<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Aktivasi Website</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.1/dist/flowbite.min.css"  rel="stylesheet" />
</head>
<body class="bg-white flex flex-col items-center justify-between min-h-screen">
    <div class="flex-grow flex items-center justify-center w-full">
        <div class="max-w-md w-full mx-auto">
            {% if messages %}
                {% for message in messages %}
                    <div class="p-4 mb-4 text-sm {% if message.tags == 'error' %}text-red-800 bg-red-100{% elif message.tags == 'success' %}text-green-800 bg-green-100{% else %}text-blue-800 bg-blue-100{% endif %} rounded-lg" role="alert">
                        {{ message }}
                    </div>
                {% endfor %}
            {% endif %}
            
            <form method="post" action="{% url 'lrnd_validate' %}">
                {% csrf_token %}
                <div class="mb-5">
                    <label for="key" class="block mb-2 text-sm font-medium text-gray-900 dark:text-white">Masukkan Kunci untuk mengaktifkan website</label>
                    <input type="text" id="key" name="key" class="bg-gray-50 border border-gray-300 text-gray-900 text-sm rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full p-2.5 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500" placeholder="Masukkan Kunci Aktivasi" required />
                </div>
                <button type="submit" class="text-white bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm w-full sm:w-auto px-5 py-2.5 text-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">Aktivasi</button>
            </form>
        </div>
    </div>
    <footer class="w-full bg-gray-100 text-center p-4">
        <p class="text-sm text-gray-600">&copy; 2024 Hak Cipta Dilindungi.</p>
    </footer>
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.1/dist/flowbite.min.js"></script>
</body>
</html>